/*
 * Copyright (C) 2020 favdb
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package storybook.model.book;

import storybook.Const;

/**
 *
 * @author favdb
 */
public class BookParamLayout extends AbstractParam {

	private boolean partTitle;
	private boolean chapterDateLocation;
	private boolean chapterDescription;
	private boolean chapterNumber;
	private boolean chapterRoman;
	private boolean chapterTitle;
	private boolean sceneDidascalie;
	private boolean sceneSeparator;
	private String sceneSeparatorValue = "";
	private boolean sceneTitle;

	public BookParamLayout(BookParam param) {
		super(param, "layout");
		init();
	}

	public BookParamLayout(String layout) {
		super(null, "layout");
		setBookLayout(this, layout);
	}

	public boolean getChapterDateLocation() {
		return (chapterDateLocation);
	}

	public void setChapterDateLocation(boolean d) {
		chapterDateLocation = d;
	}

	public boolean getChapterDescription() {
		return (chapterDescription);
	}

	public void setChapterDescription(boolean d) {
		chapterDescription = d;
	}

	public boolean getChapterNumber() {
		return (chapterNumber);
	}

	public void setChapterNumber(boolean d) {
		chapterNumber = d;
	}

	public boolean getChapterRoman() {
		return (chapterRoman);
	}

	public void setChapterRoman(boolean d) {
		chapterRoman = d;
	}

	public boolean getChapterTitle() {
		return (chapterTitle);
	}

	public void setChapterTitle(boolean d) {
		chapterTitle = d;
	}

	public boolean getPartTitle() {
		return (partTitle);
	}

	public void setPartTitle(boolean d) {
		partTitle = d;
	}

	public boolean getSceneDidascalie() {
		return (sceneDidascalie);
	}

	public void setSceneDidascalie(boolean d) {
		sceneDidascalie = d;
	}

	public boolean getSceneSeparator() {
		return (sceneSeparator);
	}

	public void setSceneSeparator(boolean d) {
		sceneSeparator = d;
	}

	public String getSceneSeparatorValue() {
		if (sceneSeparatorValue.isEmpty()) {
			return Const.SCENE_SEPARATOR;
		}
		return (sceneSeparatorValue);
	}

	public void setSceneSeparatorValue(String value) {
		sceneSeparatorValue = value;
	}

	public boolean getSceneTitle() {
		return (sceneTitle);
	}

	public void setSceneTitle(boolean d) {
		sceneTitle = d;
	}

	public static void setBookLayout(BookParamLayout layout, String in) {
		if (in.isEmpty()) {
			return;
		}
		layout.setPartTitle(in.charAt(0) == '1');
		layout.setChapterDateLocation(in.charAt(1) == '1');
		layout.setChapterDescription(in.charAt(2) == '1');
		layout.setChapterNumber(in.charAt(3) == '1');
		layout.setChapterRoman(in.charAt(4) == '1');
		layout.setChapterTitle(in.charAt(5) == '1');
		layout.setSceneDidascalie(in.charAt(6) == '1');
		layout.setSceneSeparator(in.charAt(7) == '1');
		layout.setSceneTitle(in.charAt(8) == '1');
	}

	public void setBookLayout(String in) {
		setBookLayout(this, in);
	}

	public String getBookLayout() {
		return (getBookLayout(this));
	}

	public static String getBookLayout(BookParamLayout layout) {
		String r = "";
		r += (layout.getPartTitle() ? "1" : "0");
		r += (layout.getChapterDateLocation() ? "1" : "0");
		r += (layout.getChapterDescription() ? "1" : "0");
		r += (layout.getChapterNumber() ? "1" : "0");
		r += (layout.getChapterRoman() ? "1" : "0");
		r += (layout.getChapterTitle() ? "1" : "0");
		r += (layout.getSceneDidascalie() ? "1" : "0");
		r += (layout.getSceneSeparator() ? "1" : "0");
		r += (layout.getSceneTitle() ? "1" : "0");
		return (r);
	}

	@Override
	protected void init() {
		if (param != null) {
			setBookLayout(this, param.book.getString(Book.PARAM.LAYOUT_BOOK));
			setSceneSeparatorValue(param.book.getString(Book.PARAM.LAYOUT_SCENE_SEPARATOR));
		}
	}

	@Override
	public void save() {
		if (param != null) {
			param.book.setString(Book.PARAM.LAYOUT_BOOK, getBookLayout());
			param.book.setString(Book.PARAM.LAYOUT_SCENE_SEPARATOR, getSceneSeparatorValue());
		}
	}

	public String toText(boolean html) {
		StringBuilder b = new StringBuilder();
		String eol = "\"\n";
		if (html) {
			b.append("<p>");
			eol = "\"<br>";
		}
		b.append("layout=\"").append(getBookLayout()).append(eol);
		b.append("partTitle=").append(getPartTitle() ? "true" : "false").append(eol);
		b.append("chapterTitle=").append(getChapterTitle() ? "true" : "false").append(eol);
		b.append("chapterNumber=").append(getChapterNumber() ? "true" : "false").append(eol);
		b.append("chapterRoman=").append(getChapterRoman() ? "true" : "false").append(eol);
		b.append("chapterDescription=").append(getChapterDescription() ? "true" : "false").append(eol);
		b.append("chapterDates_Locations=").append(getChapterDateLocation() ? "true" : "false").append(eol);
		b.append("sceneTitle=").append(getSceneTitle() ? "true" : "false").append(eol);
		b.append("sceneDidascalie=").append(getSceneDidascalie() ? "true" : "false").append(eol);
		b.append("sceneSeparator=").append(getSceneSeparator() ? "true" : "false").append(eol);
		b.append("sceneSeparatorValue=").append(getSceneSeparatorValue()).append(eol);
		if (html) {
			b.append("</p>");
		}
		return b.toString();
	}

	public int getHashCode() {
		return toText(false).hashCode();
	}

}
