/*
Storybook: Open Source software for novelists and authors.
Copyright (C) 2008 - 2012 Martin Mustun

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package storybook.model.hbn.entity;

import java.util.ArrayList;
import java.util.List;
import javax.swing.Icon;
import storybook.model.book.Book;
import storybook.model.hbn.entity.DB_DATA.DATA;
import resources.icons.ICONS;
import resources.icons.IconUtil;

public class Attribute extends AbstractEntity {

	private static final String TT = "Attribute";

	private String key = "";
	private String value = "";

	public Attribute() {
		super(Book.TYPE.ATTRIBUTE, "110");
	}

	public Attribute(String key, String value) {
		this();
		this.key = key;
		this.value = value;
	}

	public String getKey() {
		return this.key;
	}

	public void setKey(String key) {
		this.key = key;
	}

	public String getValue() {
		return this.value;
	}

	public void setValue(String value) {
		this.value = value;
	}

	@Override
	public Icon getIcon() {
		return (IconUtil.getIconSmall(ICONS.K.EMPTY));
	}

	@Override
	public String toCsv(String quoteStart, String quoteEnd, String separator) {
		StringBuilder b = new StringBuilder();
		b.append(quoteStart).append(getClean(this)).append(quoteEnd).append(separator);
		b.append(quoteStart).append(getClean(key)).append(quoteEnd).append(separator);
		b.append(quoteStart).append(getClean(value)).append(quoteEnd).append("\n");
		return (b.toString());
	}

	@Override
	public String toHtml() {
		return (toCsv("<td>", "</td>", "\n"));
	}

	@Override
	public String toText() {
		return (toCsv("", "", "\t"));
	}

	@Override
	public String toXml() {
		StringBuilder b = new StringBuilder();
		b.append(toXmlTab(1)).append("<").append(getObjType().toString()).append(" \n");
		b.append(xmlCommon());
		b.append(xmlAttribute(DATA.ATTRIBUTE_KEY.n(), key));
		b.append(xmlAttribute(DATA.ATTRIBUTE_VALUE.n(), value));
		b.append(toXmlTab(2)).append(" />\n");
		return (b.toString());
	}

	@Override
	public String toDetail(boolean detailed) {
		StringBuilder b = new StringBuilder();
		b.append(toHtmlDetailHeader(detailed));
		b.append(getInfo(DATA.ATTRIBUTE_KEY.i18n(), key));
		b.append(getInfo(DATA.ATTRIBUTE_VALUE.i18n(), value));
		b.append(toHtmlDetailFooter(detailed));
		return (b.toString());
	}

	@Override
	@SuppressWarnings("EqualsWhichDoesntCheckParameterClass")
	public boolean equals(Object obj) {
		if (!super.equals(obj)) {
			return false;
		}
		Attribute test = (Attribute) obj;
		boolean ret = equalsStringNullValue(key, test.getKey());
		ret = ret && equalsStringNullValue(value, test.getValue());
		return ret;
	}

	@Override
	public int hashCode() {
		return hashPlus(super.hashCode(), key, value);
	}

	public static Attribute find(List<Attribute> list, String str) {
		for (Attribute elem : list) {
			if (elem.getName().equals(str)) {
				return (elem);
			}
		}
		return (null);
	}

	public static Attribute find(List<Attribute> list, Long id) {
		for (Attribute elem : list) {
			if (elem.getId().equals(id)) {
				return (elem);
			}
		}
		return (null);
	}

	public static List<String> getTable() {
		List<String> ls = new ArrayList<>();
		String tableName = DATA.ATTRIBUTE.n();
		AbstractEntity.getTable(tableName, ls);
		ls.add(tableName + ",key,String,256");
		ls.add(tableName + ",value,String,2048");
		return (ls);
	}

}
