/*
Storybook: Open Source software for novelists and authors.
Copyright (C) 2015 FaVdB

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package storybook.ui.table;

import java.beans.PropertyChangeEvent;
import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import storybook.model.Model;
import storybook.model.book.Book;
import storybook.model.hbn.dao.RelationDAOImpl;
import storybook.model.hbn.entity.AbstractEntity;
import storybook.model.hbn.entity.DB_DATA;
import storybook.model.hbn.entity.Relationship;
import storybook.ui.MainFrame;
import static storybook.ui.table.AbsColumn.*;

/**
 * @author martin
 *
 */
@SuppressWarnings("serial")
public class RelationTable extends AbstractTable {

	public RelationTable(MainFrame mainFrame) {
		super(mainFrame, Book.TYPE.RELATION);
	}

	@Override
	public void init() {
		this.withPart = false;
	}

	@Override
	public void initUi() {
		super.initUi();
		this.toolbar.setVisible(false);
	}

	@Override
	protected void modelPropertyChangeLocal(PropertyChangeEvent evt) {
		//no specific change
	}

	@Override
	protected void sendSetEntityToEdit(int row) {
		if (row == -1) {
			return;
		}
		Relationship r = (Relationship) getEntityFromRow(row);
		if (r != null) {
			mainFrame.showEditorAsDialog(r);
		}
	}

	@Override
	protected void sendSetNewEntityToEdit(AbstractEntity entity) {
		mainFrame.showEditorAsDialog(entity);
	}

	@Override
	protected synchronized void sendDeleteEntity(int row) {
		Relationship r = (Relationship) getEntityFromRow(row);
		if (r != null) {
			ctrl.deleteEntity(r);
		}
	}

	@Override
	protected synchronized void sendDeleteEntities(List<AbstractEntity> entities) {
		ArrayList<Long> ids = new ArrayList<>();
		for (AbstractEntity entity : entities) {
			Relationship r = (Relationship) entity;
			ids.add(r.getId());
		}
		ctrl.deletemultiEntity(Book.TYPE.TAGLINK, ids);
	}

	@Override
	protected AbstractEntity getEntity(Long id) {
		Model model = mainFrame.getBookModel();
		Session session = model.beginTransaction();
		RelationDAOImpl dao = new RelationDAOImpl(session);
		Relationship r = dao.find(id);
		model.commit();
		return r;
	}

	@Override
	public void updateRow(AbstractEntity entity) {
		// refresh for scene, person, item, tag, location
		switch (Book.getTYPE(entity)) {
			case ITEM:
			case LOCATION:
			case PERSON:
			case SCENE:
			case TAG:
				fillTable();
				break;
			default:
				break;
		}
	}

	@Override
	public List<AbsColumn> getColumns(AbstractEntity entity) {
		List<AbsColumn> cols = super.getColumns(entity);

		cols.add(new AbsColumn(mainFrame, cols, DB_DATA.DATA.SCENE_START));
		cols.add(new AbsColumn(mainFrame, cols, DB_DATA.DATA.SCENE_END));
		cols.add(new AbsColumn(mainFrame, cols, DB_DATA.DATA.PERSONS, TCR_ENTITIES));
		cols.add(new AbsColumn(mainFrame, cols, DB_DATA.DATA.LOCATIONS, TCR_ENTITIES));
		cols.add(new AbsColumn(mainFrame, cols, DB_DATA.DATA.ITEMS, TCR_ENTITIES));

		this.getColumnsEnd(cols, entity);

		return (cols);
	}

	@Override
	public List<Object> getRow(AbstractEntity entity) {
		List<Object> cols = super.getRow(entity);
		Relationship e = (Relationship) entity;
		cols.add(e.getStartScene());
		cols.add(e.getEndScene());
		cols.add(e.getPersons());
		cols.add(e.getLocations());
		cols.add(e.getItems());
		getRowEnd(cols, entity);
		return (cols);
	}

}
